<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns="http://www.w3.org/1999/xhtml"> 

<xsl:output method="xhtml:xhtml"/>
 
 
<!-- METHOD -->
<xsl:template name="method">
  <xsl:param name="module"/>
  <xsl:param name="standard"/>
  <xsl:param name="interface"><xsl:value-of select="../@name"/></xsl:param>
  <html>
    <head>
      <title> Method <xsl:value-of select="@name"/> of interface <xsl:value-of select="$interface"/> </title>
      <link href="../global.css" rel="stylesheet" type="text/css" />
      <link href="../reference.css" rel="stylesheet" type="text/css" />
      <link href="../example.css" rel="stylesheet" type="text/css" />
    </head>
    <body>
    
      <!-- HEADER -->
      <xsl:call-template name="header">
        <xsl:with-param name="standard"><xsl:value-of select="$standard"/></xsl:with-param>
        <xsl:with-param name="module"><xsl:value-of select="$module"/></xsl:with-param>
        <xsl:with-param name="interface"><xsl:value-of select="$interface"/></xsl:with-param>
        <xsl:with-param name="property"><xsl:value-of select="@name"/></xsl:with-param>
      </xsl:call-template>
      
      <!-- METHOD body -->
      <h2>
        <xsl:value-of select="@name"/>
        (method
        <xsl:if test="@deprecated='yes'">
          <xsl:text>,&#160;</xsl:text>
          <span class="deprecated">deprecated in HTML 4.01</span>
        </xsl:if>
        )
      </h2>

      <div class="bold2">Owning interface and usage: &#160; </div>
      <div class="dataBody">
        <a href="interface_{$interface}.html" class="interface"><xsl:value-of select="$interface"/></a><xsl:text>.</xsl:text><span class="method"><xsl:value-of select="@name"/></span>(<xsl:apply-templates select="parameter | parameters/param" mode="forSyntax"/>)
      </div>

      <br />
      <div class="bold2">Member of these other interfaces : &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select=".." mode="members"/>
      </div>

      <br />
      <div class="bold2">Description: &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select="description|descr"/>
      </div>

      <xsl:if test="group">
        <br />
        <xsl:apply-templates select="group"/>
      </xsl:if>

      <br />
      <div class="bold2">Parameters: &#160; </div>
      <div class="dataBody">
        <xsl:choose>
          <xsl:when test="parameter | parameters">
            <xsl:apply-templates select="parameter | parameters/param" mode="main"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>none</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </div>

      <br />
      <div class="bold2">Returns: &#160; </div>
      <div class="dataBody">
        <xsl:choose>
          <xsl:when test="returns">
            <xsl:apply-templates select="returns" mode="main"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>nothing</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </div>

      <br />
      <div class="bold2">Exceptions: &#160; </div>
      <div class="dataBody">
        <xsl:choose>
          <xsl:when test="exception | raises/exception">
            <xsl:apply-templates select="exception | raises/exception"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:text>none</xsl:text>
          </xsl:otherwise>
        </xsl:choose>
      </div>

    <xsl:if test="not(normalize-space(note)='')">
      <br />
      <div class="bold2">Note: &#160; </div>
      <div class="dataBody">
        <xsl:apply-templates select="note"/>
      </div>
    </xsl:if>

    <xsl:if test="$examplesDoc//example[@forInterface=current()/parent::interface/@name and @forName=current()/@name]">
      <br />
      <br />
      <a name="example"/>
      <fieldset>
        <legend class="bold2">Example:</legend>
        <div>
          <xsl:apply-templates select="$examplesDoc//example[@forInterface=current()/parent::interface/@name and @forName=current()/@name]"/>
        </div>
      </fieldset>
    </xsl:if>

    <!-- FOOTER -->
    <xsl:call-template name="footer"/>

    </body>
  </html>
</xsl:template>

<xsl:template match="parameter|param" mode="main">
  <table border="0" cellpadding="0" _cellspacing="0">
    <tr align="left" valign="top">
      <td>
        <xsl:call-template name="interfaceDetector"/>&#160;<span class="parameter"><xsl:value-of select="@name"/></span>
      </td>
      <td><xsl:text>&#160;-&#160;</xsl:text></td>
      <td> <xsl:apply-templates select="desc|descr"/> </td>
    </tr>
  </table>
</xsl:template>

<xsl:template match="parameter|param" mode="forSyntax">
  <span class="parameter"><xsl:value-of select="@name"/></span>
  <xsl:if test="not(position()=last())">, </xsl:if>
</xsl:template>

<xsl:template match="returns" mode="main">
  <xsl:choose>
    <xsl:when test="@name"> <!-- so it should be interface -->
      <xsl:variable name="valueOfNameAttr">
        <xsl:value-of select="@name"/>
      </xsl:variable>
      <xsl:variable name="nameOfInterface">
        <xsl:choose>
          <xsl:when test="contains($valueOfNameAttr,' ')">
            <xsl:value-of select="substring-before($valueOfNameAttr,' ')"/>
            <xsl:variable name="secondValue">
              <xsl:value-of select="substring-after($valueOfNameAttr,' ')"/>
            </xsl:variable>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$valueOfNameAttr"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="prePath">
        <xsl:choose>
          <xsl:when test="@module"><xsl:text>../</xsl:text><xsl:value-of select="@module"/><xsl:text>/</xsl:text></xsl:when>
          <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:variable name="path">
        <xsl:value-of select="$prePath"/><xsl:text>interface_</xsl:text><xsl:value-of select="$nameOfInterface"/><xsl:text>.html</xsl:text>
      </xsl:variable>
      <a href="{$path}" class="interface"><xsl:value-of select="$nameOfInterface"/></a>
      <!-- Ooops ^_^
      <xsl:if test="contains($valueOfNameAttr,' ')">
        <xsl:text>&#160;or&#160;</xsl:text><span class="code"><xsl:value-of select="$secondValue"/></span>
      </xsl:if>
      -->
    </xsl:when>
    <xsl:otherwise>
      <a href="../_glossary.html#{@type}" class="code"><xsl:value-of select="@type"/></a>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:text>&#160;-&#160;</xsl:text>
  <xsl:apply-templates select="desc|descr"/>
</xsl:template>

</xsl:stylesheet>
